@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: adapter.py 783 2010-01-09 14:28:06Z icemac $
+# $Id: adapter.py 1120 2010-10-04 18:52:13Z icemac $
 
 import zope.interface
 import zope.schema.interfaces
@@ -26,6 +26,12 @@ def title_for_choice_value(field, value):
     return factory.getTitle(value)
 
 
+@zope.interface.implementer(icemac.addressbook.interfaces.ITitle)
+def obj_dot_title(obj):
+    "ITitle adapter for objects those title is stored on the title attribute."
+    return obj.title
+
+
 @zope.component.adapter(zope.interface.Interface)
 @zope.interface.implementer(icemac.addressbook.interfaces.ITitle)
 def default_title(obj):
