@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2009-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: principals.py 867 2010-03-07 15:55:39Z icemac $
+# $Id: principals.py 1183 2010-11-23 17:17:09Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.addressbook.browser.base
@@ -107,6 +107,7 @@ password_not_required = z3c.form.widget.StaticWidgetAttribute(
 
 class EditForm(icemac.addressbook.browser.base.GroupEditForm):
 
+    label = _(u'Edit user')
     groups = (icemac.addressbook.browser.metadata.MetadataGroup,)
     interface = icemac.addressbook.principals.interfaces.IPrincipal
     next_url = 'parent'
@@ -148,13 +149,45 @@ class EditForm(icemac.addressbook.browser.base.GroupEditForm):
         self.redirect_to_next_url('object', '@@delete_user.html')
 
     def applyChanges(self, data):
+        current_principal_id = (
+            self.request.interaction.participations[0].principal.id)
+        current_login_name = None
+        auth = zope.component.getUtility(
+            zope.authentication.interfaces.IAuthentication)
+        for key, plugin in auth.getAuthenticatorPlugins():
+            principal_info = plugin.principalInfo(current_principal_id)
+            if principal_info is not None:
+                current_login_name = principal_info.login
+                break
+
+        old_login_name = self.context.login
+        editing_own_data = (old_login_name == current_login_name)
         try:
-            super(EditForm, self).applyChanges(data)
+            changes = super(EditForm, self).applyChanges(data)
         except ValueError, e:
             transaction.doom()
             raise z3c.form.interfaces.ActionExecutionError(
                 zope.interface.Invalid(_(e.args[0])))
 
+        if not editing_own_data:
+            # User is not editing his own data principal's data:
+            return changes
+
+        changed_field_names = []
+        changed_field_names.extend(
+            changes.get(
+                icemac.addressbook.principals.interfaces.IPrincipal, []))
+        changed_field_names.extend(
+            changes.get(
+                icemac.addressbook.principals.interfaces.IPasswordFields, []))
+        if 'login' in changed_field_names:
+            self.send_flash(_('You changed the login name, please re-login.'))
+        if ('password' in changed_field_names and
+            'password_repetition' in changed_field_names and
+            data['password']):
+            self.send_flash(_('You changed the password, please re-login.'))
+        return changes
+
 
 class EditForm_password_Validator(z3c.form.validator.SimpleFieldValidator):
     """Validator for data field in add form."""
