@@ -1,19 +1,22 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 875 2010-03-20 10:25:07Z icemac $
+# $Id: tests.py 1183 2010-11-23 17:17:09Z icemac $
 
 import icemac.addressbook.testing
 import zope.testing.renormalizing
 
+
 def test_suite():
     suite = icemac.addressbook.testing.FunctionalDocFileSuite(
+        "browser/about/about.txt",
         "browser/addressbook/addressbook.txt",
         "browser/authentication/login.txt",
         "browser/entities/bugfix.txt",
         "browser/entities/delete_choice_value.txt",
         "browser/entities/entities.txt",
         "browser/entities/file.txt",
+        "browser/entities/sortorder.txt",
         "browser/export/export.txt",
         "browser/export/translation.txt",
         "browser/export/userfields.txt",
@@ -22,9 +25,11 @@ def test_suite():
         "browser/person/clone.txt",
         "browser/person/file.txt",
         "browser/person/person.txt",
+        "browser/person/sortorder.txt",
         "browser/person/translation.txt",
         "browser/principals/principals.txt",
         "browser/rootfolder/rootfolder.txt",
+        "browser/search/delete.txt",
         "browser/search/search.txt",
         )
     suite.addTest(
@@ -34,4 +39,3 @@ def test_suite():
             checker=zope.testing.renormalizing.RENormalizing([])
             ))
     return suite
-
