@@ -1,15 +1,15 @@
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: __init__.py 865 2010-03-07 15:52:31Z icemac $
+# $Id: __init__.py 1152 2010-10-28 18:48:52Z icemac $
 """Database initialisation and upgrading."""
 
-import zope.app.generations.generations
+import zope.generations.generations
 
 
-GENERATION = 9
+GENERATION = 16
 
 
-manager = zope.app.generations.generations.SchemaManager(
+manager = zope.generations.generations.SchemaManager(
     minimum_generation=GENERATION,
     generation=GENERATION,
     package_name='icemac.addressbook.generations')
