@@ -1,20 +1,30 @@
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: utils.py 805 2010-01-23 20:31:46Z icemac $
+# $Id: utils.py 1090 2010-09-18 12:23:06Z icemac $
 
-import zope.app.generations.utility
+import zope.generations.utility
 import icemac.addressbook.interfaces
 import icemac.addressbook.addressbook
+import logging
+
+
+logger = logging.getLogger('evolve')
 
 
 def evolve_addressbooks(func):
     "Decorator which evolves address books."
     def decorated(context):
-        root = zope.app.generations.utility.getRootFolder(context)
-        addressbooks = zope.app.generations.utility.findObjectsProviding(
+        root = zope.generations.utility.getRootFolder(context)
+        addressbooks = zope.generations.utility.findObjectsProviding(
             root, icemac.addressbook.interfaces.IAddressBook)
         for addressbook in addressbooks:
-            func(addressbook)
+            logger.info('evolving %r' % addressbook)
+            old_site = zope.site.hooks.getSite()
+            try:
+                zope.site.hooks.setSite(addressbook)
+                func(addressbook)
+            finally:
+                zope.site.hooks.setSite(old_site)
     return decorated
 
 
