@@ -3,12 +3,13 @@
 # See also LICENSE.txt
 
 import icemac.addressbook.testing
-import icemac.addressbook.preferences
+
 
 def test_suite():
     return icemac.addressbook.testing.FunctionalDocFileSuite(
+        'person-list-batching.txt',
         'person-list-userfields.txt',
         'person-list.txt',
-        'person-list-batching.txt',
         'preferences.txt',
+        'sortorder.txt',
         package="icemac.addressbook.preferences")
