@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: utils.py 783 2010-01-09 14:28:06Z icemac $
+# $Id: utils.py 1183 2010-11-23 17:17:09Z icemac $
 
 import zope.container.interfaces
 import zope.event
@@ -49,8 +49,19 @@ create_and_add_with_set_site = set_site(create_and_add)
 
 
 def iter_by_interface(container, interface):
-    "Iterate a container and return only objects providing the specified iface."
+    "Iterate a container and return only objects providing a specified iface."
     for obj in container.values():
         if interface.providedBy(obj):
             yield obj
 
+
+def utility_locally_registered(site, interface):
+    """Test, whether a utility is registered on the site manager of the `site`.
+
+    interface ... interface the utility is registered for
+
+    """
+    for registration in site.getSiteManager().registeredUtilities():
+        if registration.provided == interface:
+            return True
+    return False
