@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: address.py 1009 2010-08-15 14:20:55Z icemac $
+# $Id: address.py 1183 2010-11-23 17:17:09Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.addressbook.entities
@@ -56,6 +56,7 @@ def postal_address_title(address):
         title = ', '.join(translated_values)
     return title
 
+
 class EMailAddress(
     persistent.Persistent, zope.container.contained.Contained):
     """An e-mail address."""
@@ -137,53 +138,13 @@ def phone_number_title(tel):
     return title
 
 
-address_mapping = (
-    dict(interface=icemac.addressbook.interfaces.IPostalAddress,
-         title=_(u'postal address'),
-         prefix='postal_address',
-         class_=PostalAddress),
-    dict(interface=icemac.addressbook.interfaces.IPhoneNumber,
-         title=_(u'phone number'),
-         prefix='phone_number',
-         class_=PhoneNumber),
-    dict(interface=icemac.addressbook.interfaces.IEMailAddress,
-         title=_(u'e-mail address'),
-         prefix='email_address',
-         class_=EMailAddress),
-    dict(interface=icemac.addressbook.interfaces.IHomePageAddress,
-         title=_(u'home page address'),
-         prefix='home_page_address',
-         class_=HomePageAddress),
-    )
-
-
-def object_to_prefix(obj):
-    """Convert an object to its prefix."""
-    for data in address_mapping:
-        if data['interface'].providedBy(obj):
-            return data['prefix']
-    raise KeyError(obj)
-
-
-def object_to_title(obj):
-    """Convert an object to its title."""
-    for data in address_mapping:
-        if data['interface'].providedBy(obj):
-            return data['title']
-    raise KeyError(obj)
-
-
-def object_to_class(obj):
-    """Convert an object to its class."""
-    for data in address_mapping:
-        if data['interface'].providedBy(obj):
-            return data['class_']
-    raise KeyError(obj)
-
-
-def prefix_to_class(prefix):
-    """Convert a prefix to its class."""
-    for address in icemac.addressbook.address.address_mapping:
-        if address['prefix'] == prefix:
-            return address['class_']
-    raise KeyError(prefix)
+def default_attrib_name_to_entity(default_attrib_name):
+    "Convert the name of a default attrib to the entity where it is defined on"
+    entities = zope.component.getUtility(
+        icemac.addressbook.interfaces.IEntities).getEntities(sorted=False)
+    for candidate in entities:
+        candidate_default_attrib = candidate.tagged_values.get(
+            'default_attrib')
+        if candidate_default_attrib == default_attrib_name:
+            return candidate
+    raise ValueError("Unknown default_attrib_name: %r" % default_attrib_name)
