@@ -1,12 +1,14 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 1009 2010-08-15 14:20:55Z icemac $
+# $Id: interfaces.py 1164 2010-11-17 16:54:23Z icemac $
 
+from icemac.addressbook.i18n import _
 import z3c.form.interfaces
 import z3c.formui.interfaces
 import z3c.layer.pagelet
 import z3c.preference.interfaces
+import zope.interface
 
 
 class IAddressBookLayer(
@@ -20,3 +22,10 @@ class IAddressBookBrowserSkin(
     z3c.formui.interfaces.IDivFormLayer,
     IAddressBookLayer):
     """The address book browser skin using the div-based layout."""
+
+
+class IPersonCount(zope.interface.Interface):
+    "Number of persons for deletion."
+
+    count = zope.schema.Int(title=_(u'number of persons'), required=False)
+    notes = zope.schema.TextLine(title=_(u'notes'), required=False)
