@@ -1,14 +1,16 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: keyword.py 799 2010-01-23 14:24:17Z icemac $
+# $Id: keyword.py 1183 2010-11-23 17:17:09Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import gocept.reference.interfaces
 import icemac.addressbook.browser.base
+import icemac.addressbook.browser.metadata
+import icemac.addressbook.browser.table
 import icemac.addressbook.interfaces
 import z3c.form.button
-import icemac.addressbook.browser.metadata
+import z3c.table.column
 
 
 class AddForm(icemac.addressbook.browser.base.BaseAddForm):
@@ -28,6 +30,7 @@ def can_delete_keyword(form):
             form.context).is_referenced()
         )
 
+
 class EditForm(icemac.addressbook.browser.base.GroupEditForm):
 
     groups = (icemac.addressbook.browser.metadata.MetadataGroup,)
@@ -63,3 +66,21 @@ class DeleteForm(icemac.addressbook.browser.base.BaseDeleteForm):
     label = _(u'Do you really want to delete this keyword?')
     interface = icemac.addressbook.interfaces.IKeyword
     field_names = ('title', )
+
+
+class Table(icemac.addressbook.browser.table.Table):
+    """List keywords in address book."""
+
+    no_rows_message = _(u'No keywords defined yet.')
+
+    def setUpColumns(self):
+        "Return the previously computed columns."
+        return [z3c.table.column.addColumn(
+            self, icemac.addressbook.browser.table.TitleLinkColumn, 'keyword',
+            header=_(u'keyword')),
+                ]
+
+    @property
+    def values(self):
+        "The values are stored on the context."
+        return self.context.get_keywords()
