@@ -1,17 +1,17 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: person.py 799 2010-01-23 14:24:17Z icemac $
+# $Id: person.py 1183 2010-11-23 17:17:09Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import gocept.reference.interfaces
-import icemac.addressbook.address
 import icemac.addressbook.browser.base
 import icemac.addressbook.browser.metadata
 import icemac.addressbook.interfaces
 import icemac.addressbook.person
 import icemac.addressbook.sources
 import icemac.addressbook.utils
+import transaction
 import z3c.form.button
 import z3c.form.datamanager
 import z3c.form.form
@@ -30,12 +30,12 @@ class AddGroup(icemac.addressbook.browser.base.PrefixGroup):
         self.prefix = prefix
 
 
-class EditGroup(AddGroup):
-    "PrefixGroup for EditForm."
+class PersonEditGroup(AddGroup):
+    """PrefixGroup for addresses IPerson in EditForm."""
 
-    def __init__(
-        self, context, request, parent, interface, label, prefix, index, key):
-        super(EditGroup, self).__init__(
+    def __init__(self, context, request, parent, interface, label, prefix,
+                 index, key):
+        super(PersonEditGroup, self).__init__(
             context, request, parent, interface, label, prefix)
         self.prefix = "%s_%s" % (prefix, index)
         self.key = key
@@ -44,25 +44,25 @@ class EditGroup(AddGroup):
         self.groups = [
             icemac.addressbook.browser.metadata.MetadataGroup(
                 self.getContent(), self.request, self)]
-        super(EditGroup, self).update()
+        super(PersonEditGroup, self).update()
+
+
+class AddressEditGroup(PersonEditGroup):
+    "PrefixGroup for addresses in EditForm."
 
     def getContent(self):
         return self.context[self.key]
 
 
-class FileEditGroup(EditGroup):
-    """EditGroup for icemac.addressbook.file.interfaces.IFile objects."""
-
-    @property
-    def fields(self):
-        return super(FileEditGroup, self).fields
+class FileEditGroup(AddressEditGroup):
+    "AddressEditGroup for icemac.addressbook.file.interfaces.IFile objects."
 
 
 class DefaultSelectGroup(icemac.addressbook.browser.base.PrefixGroup):
     """Group to select the default addresses."""
 
     interface = icemac.addressbook.interfaces.IPersonDefaults
-    label = _(u'main adresses and numbers')
+    label = icemac.addressbook.person.person_defaults_entity.title
     prefix = 'defaults'
 
 
@@ -70,32 +70,51 @@ class PersonAddForm(z3c.form.group.GroupForm,
                     icemac.addressbook.browser.base.BaseAddForm):
 
     label = _(u'Add new person')
-    interface = icemac.addressbook.interfaces.IPerson
     next_url = 'parent'
+    interface_for_menu = icemac.addressbook.interfaces.IPerson
 
     def __init__(self, *args, **kw):
         super(PersonAddForm, self).__init__(*args, **kw)
         context = self.context
         request = self.request
-        groups = [AddGroup(context, request, self, address['interface'],
-                           _(address['title']), address['prefix'])
-                  for address in icemac.addressbook.address.address_mapping]
+        entities = zope.component.getUtility(
+            icemac.addressbook.interfaces.IEntities)
+        groups = [AddGroup(context, request, self, entity.interface,
+                           entity.title, entity.name)
+                  for entity in entities.getMainEntities()]
         self.groups = tuple(groups)
 
+    def update(self):
+        super(PersonAddForm, self).update()
+        # This call is needed because GroupForm does not do a super call.
+        icemac.addressbook.browser.base.get_needed_resources(self)
+
     def createAndAdd(self, data):
-        person = icemac.addressbook.browser.base.create(
-            self, icemac.addressbook.person.Person, data)
+        # Create person first
+        person_entity = icemac.addressbook.interfaces.IEntity(
+            icemac.addressbook.interfaces.IPerson)
+        person_entity_name = person_entity.name
+        for group in self.groups:
+            if group.prefix == person_entity_name:
+                # found person group, now can create person object
+                person = icemac.addressbook.browser.base.create(
+                    group, person_entity.getClass(), data)
+                break
         self._name = icemac.addressbook.utils.add(self.context, person)
         for group in self.groups:
+            if group.prefix == person_entity_name:
+                # already created above
+                continue
+            entity = icemac.addressbook.interfaces.IEntity(group.prefix)
             obj = icemac.addressbook.browser.base.create(
-                group, icemac.addressbook.address.prefix_to_class(group.prefix),
-                data)
+                group, entity.getClass(), data)
             icemac.addressbook.utils.add(person, obj)
             # handling of default addresses: the first address is
             # saved as default
-            default_attrib = 'default_%s' % group.prefix
+            default_attrib = entity.tagged_values['default_attrib']
             if getattr(person, default_attrib, None) is None:
                 setattr(person, default_attrib, obj)
+        self.obj = person
         return person
 
 
@@ -109,39 +128,67 @@ def person_deletable(form):
 class PersonEditForm(icemac.addressbook.browser.base.GroupEditForm):
 
     label = _(u'Edit person data')
-    interface = icemac.addressbook.interfaces.IPerson
     next_url = 'parent'
+    interface_for_menu = icemac.addressbook.interfaces.IPerson
 
     def __init__(self, *args, **kw):
         super(PersonEditForm, self).__init__(*args, **kw)
-        groups = [icemac.addressbook.browser.metadata.MetadataGroup,
-                  DefaultSelectGroup]
-        for address in icemac.addressbook.address.address_mapping:
+        entity_util = zope.component.getUtility(
+            icemac.addressbook.interfaces.IEntities)
+        entities = entity_util.getMainEntities(sorted=False)
+        file_entity = icemac.addressbook.interfaces.IEntity(
+            icemac.addressbook.file.interfaces.IFile)
+        defaults_entity = icemac.addressbook.interfaces.IEntity(
+            icemac.addressbook.interfaces.IPersonDefaults)
+        entities.extend([file_entity, defaults_entity])
+
+        groups = []
+        for entity in icemac.addressbook.entities.sorted_entities(entities):
             index = 0
-            default_obj = getattr(self.context,
-                                  'default_%s' % address['prefix'])
+
+            # Special handling for IPerson
+            if entity.interface == icemac.addressbook.interfaces.IPerson:
+                group = PersonEditGroup(
+                    self.context, self.request, self, entity.interface,
+                    entity.title, entity.name, index,
+                    self.context.__name__)
+                groups.append(group)
+                continue
+
+            # Special handling for IPersonDefaults
+            IPersonDefaults = icemac.addressbook.interfaces.IPersonDefaults
+            if entity.interface == IPersonDefaults:
+                groups.append(
+                    DefaultSelectGroup(self.context, self.request, self))
+                continue
+
+            is_ifile = (
+                entity.interface == icemac.addressbook.file.interfaces.IFile)
+            if is_ifile:
+                # IFile needs a special group and has a fix title
+                group_class = FileEditGroup
+                obj_title = entity.title
+            else:
+                # for the other entities the title depends on whether being
+                # main address or not
+                default_attrib = entity.tagged_values.get('default_attrib')
+                default_obj = getattr(self.context, default_attrib)
+                group_class = AddressEditGroup
+
             for obj in icemac.addressbook.utils.iter_by_interface(
-                    self.context, address['interface']):
-                if obj == default_obj:
-                    obj_title = _(u'main ${address}')
-                else:
-                    obj_title = _(u'other ${address}')
-                obj_title = _(obj_title, mapping={'address': address['title']})
-                group = EditGroup(
-                    self.context, self.request, self, address['interface'],
-                    obj_title, address['prefix'], index, obj.__name__)
+                    self.context, entity.interface):
+                if not is_ifile:
+                    if obj == default_obj:
+                        obj_title = _(u'main ${address}')
+                    else:
+                        obj_title = _(u'other ${address}')
+                    obj_title = _(obj_title, mapping={'address': entity.title})
+                group = group_class(
+                    self.context, self.request, self, entity.interface,
+                    obj_title, entity.name, index, obj.__name__)
                 groups.append(group)
                 index += 1
 
-        iface = icemac.addressbook.file.interfaces.IFile
-        for obj in icemac.addressbook.utils.iter_by_interface(
-                self.context, iface):
-            group = FileEditGroup(
-                self.context, self.request, self, iface, _(u'file'), 'file',
-                index, obj.__name__)
-            groups.append(group)
-            index += 1
-
         self.groups = tuple(groups)
 
     @z3c.form.button.buttonAndHandler(_('Apply'), name='apply')
@@ -153,12 +200,19 @@ class PersonEditForm(icemac.addressbook.browser.base.GroupEditForm):
                 continue
             prefix = z3c.form.util.expandPrefix(group.prefix)
             icemac.addressbook.browser.file.file.update_blob(
-                group.widgets[prefix+'data'], group.getContent())
+                group.widgets[prefix + 'data'], group.getContent())
 
     @z3c.form.button.buttonAndHandler(_('Cancel'), name='cancel')
     def handleCancel(self, action):
         self.status = self.noChangesMessage
 
+    @z3c.form.button.buttonAndHandler(
+        _(u'Clone person'), name='clone_person',
+        condition=icemac.addressbook.browser.base.can_access(
+            '@@clone.html'))
+    def handleClonePerson(self, action):
+        self.redirect_to_next_url('object', '@@clone.html')
+
     @z3c.form.button.buttonAndHandler(
         _(u'Delete whole person'), name='delete_person',
         condition=icemac.addressbook.browser.base.all_(
@@ -191,7 +245,9 @@ class PersonEditForm(icemac.addressbook.browser.base.GroupEditForm):
                 zope.lifecycleevent.Attributes(interface, *names)
                 for interface, names in changes.items()]
             zope.event.notify(
-                zope.lifecycleevent.ObjectModifiedEvent(content, *descriptions))
+                zope.lifecycleevent.ObjectModifiedEvent(
+                    content, *descriptions))
+        return changed
 
 
 class KeywordDataManager(z3c.form.datamanager.AttributeField):
@@ -211,39 +267,39 @@ class DeletePersonForm(icemac.addressbook.browser.base.BaseDeleteForm):
         try:
             super(DeletePersonForm, self)._do_delete()
         except gocept.reference.interfaces.IntegrityError:
-            pass # XXX abort transaction (IntegrityError dooms it) and
-                 # set notice using z3c.flashmessage
+            transaction.abort()
+            message = _(
+                'Failed to delete person: This person is connected to '
+                'a user. To delete this person, delete the user first.')
+            zope.component.getUtility(
+                z3c.flashmessage.interfaces.IMessageSource).send(message)
 
 
 class PersonEntriesSource(
     zc.sourcefactory.contextual.BasicContextualSourceFactory):
-    "Source to select entries from person."
+    "Source to select entries (addresses, files, ...) from a person."
 
     def getValues(self, context):
-        for address in icemac.addressbook.address.address_mapping:
+        entities = zope.component.getUtility(
+            icemac.addressbook.interfaces.IEntities).getEntities()
+        for entity in entities:
+            if entity.interface is None:
+                continue
             for value in icemac.addressbook.sources.ContextByInterfaceSource(
-                    address['interface']).factory.getValues(context):
+                    entity.interface).factory.getValues(context):
                 yield value
-        for value in icemac.addressbook.sources.ContextByInterfaceSource(
-            icemac.addressbook.file.interfaces.IFile).factory.getValues(
-            context):
-            yield value
 
     def getTitle(self, context, value):
-        try:
-            title_prefix = icemac.addressbook.address.object_to_title(value)
-        except KeyError:
-            # up to now there are only files besides the address entries
-            title_prefix = _('file')
-        title = icemac.addressbook.interfaces.ITitle(value)
-        if title_prefix:
-            title = _('${prefix} -- ${title}',
-                      mapping=dict(prefix=title_prefix, title=title))
+        entity = icemac.addressbook.interfaces.IEntity(value)
+        title = _('${prefix} -- ${title}',
+                  mapping=dict(
+                      prefix=entity.title,
+                      title=icemac.addressbook.interfaces.ITitle(value)))
         return title
 
 
 class IPersonEntries(zope.interface.Interface):
-    """Content entries of an object."""
+    """Content entries of a person."""
 
     entry = zope.schema.Choice(
         title=_(u'Entries'), source=PersonEntriesSource())
