@@ -1,15 +1,14 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: base.py 783 2010-01-09 14:28:06Z icemac $
-
-import z3c.form.field
-import z3c.formui.form
-import z3c.form.button
-
-import icemac.addressbook.browser.search.interfaces
+# $Id: base.py 1183 2010-11-23 17:17:09Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
+import icemac.addressbook.browser.search.interfaces
+import z3c.form.button
+import z3c.form.field
+import z3c.formui.form
+import zope.interface
 
 
 class BaseView(object):
@@ -28,8 +27,8 @@ class BaseView(object):
 
 
 class BaseSearchForm(z3c.formui.form.Form):
-    
-    interface = None # to be set in child class
+
+    interface = None  # to be set in child class
 
     ignoreContext = True
     formErrorsMessage = _('There were some errors.')
@@ -45,3 +44,16 @@ class BaseSearchForm(z3c.formui.form.Form):
             self.status = self.formErrorsMessage
             return
         self.__parent__.search_params = data
+
+
+class BaseSearch(object):
+    """Base class for search adapter."""
+
+    zope.interface.implements(
+        icemac.addressbook.browser.search.interfaces.ISearch)
+
+    def __init__(self, *args):
+        pass
+
+    def search(self, **kw):
+        raise NotImplementedError
