@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 876 2010-03-20 10:40:34Z icemac $
+# $Id: interfaces.py 1183 2010-11-23 17:17:09Z icemac $
 
 import z3c.menu.ready2go
 import zope.interface
@@ -24,4 +24,4 @@ class ISearch(zope.interface.Interface):
     """A search."""
 
     def search(**kw):
-        """Search for given keyword arguments and return iterable of results."""
+        "Search for given keyword arguments and return iterable of results."
