@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: keyword.py 791 2010-01-17 17:18:16Z icemac $
+# $Id: keyword.py 1183 2010-11-23 17:17:09Z icemac $
 
 import persistent
 import zope.catalog.interfaces
@@ -22,8 +22,8 @@ class KeywordContainer(zope.container.btree.BTreeContainer):
     zope.interface.implements(icemac.addressbook.interfaces.IKeywords)
 
     def get_keywords(self):
-        # XXX sorting should be done in presentation layer!
-        return sorted(self.values(), key=lambda x: x.title)
+        # sorting will be done in presentation layer
+        return self.values()
 
     def get_keyword_by_title(self, title, default=None):
         for keyword in self.values():
@@ -31,6 +31,7 @@ class KeywordContainer(zope.container.btree.BTreeContainer):
                 return keyword
         return default
 
+
 class Keyword(persistent.Persistent, zope.container.contained.Contained):
     "A keyword."
     zope.interface.implements(icemac.addressbook.interfaces.IKeyword)
@@ -60,12 +61,6 @@ def changed(obj, event):
             break
 
 
-@zope.component.adapter(icemac.addressbook.interfaces.IKeyword)
-@zope.interface.implementer(icemac.addressbook.interfaces.ITitle)
-def title(keyword):
-    return keyword.title
-
-
 def uniqueTitles(obj, event):
     if getattr(obj, '__parent__', None) is None:
         return
