@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 783 2010-01-09 14:28:06Z icemac $
+# $Id: tests.py 1183 2010-11-23 17:17:09Z icemac $
 
 import gocept.reference.verify
 import icemac.addressbook.principals.interfaces
@@ -22,11 +22,11 @@ class TestInterfaces(unittest.TestCase):
         gocept.reference.verify.verifyObject(
             icemac.addressbook.principals.interfaces.IPrincipal, principal)
         zope.interface.verify.verifyObject(
-            icemac.addressbook.principals.interfaces.IPasswordFields, principal)
+            icemac.addressbook.principals.interfaces.IPasswordFields,
+            principal)
         zope.interface.verify.verifyObject(
             icemac.addressbook.principals.interfaces.IRoles, principal)
 
 
 def test_suite():
     return icemac.addressbook.testing.AddressBookUnittestSuite(TestInterfaces)
-
